==> skill-core-0.0.4-sources.jar: com/ptteng/sca/common/skill/client/OrderSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.common.skill.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.skill.model.Order;
import com.ptteng.common.skill.service.OrderService;

import java.util.List;
import java.util.Map;

public class OrderSCAClient implements OrderService {

    private OrderService orderService;

	public OrderService getOrderService() {
		return orderService;
	}
	
	
	public void setOrderService(OrderService orderService) {
		this.orderService =orderService;
	}
	
	
			   
		@Override
		public Long insert(Order order)throws ServiceException, ServiceDaoException{
		
		return orderService.insert(order);
		          
		
		}	
		  
    	   
		@Override
		public List<Order> insertList(List<Order> orderList)throws ServiceException, ServiceDaoException{
		
		return orderService.insertList(orderList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return orderService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(Order order)throws ServiceException, ServiceDaoException{
		
		return orderService.update(order);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<Order> orderList)throws ServiceException, ServiceDaoException{
		
		return orderService.updateList(orderList);
		          
		
		}	
		  
    	   
		@Override
		public Order getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return orderService.getObjectById(id);
		          
		
		}

	@Override
	public Order getObjectByOrderId(String orderId) throws ServiceException, ServiceDaoException {
		return orderService.getObjectByOrderId(orderId);
	}


	@Override
		public List<Order> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return orderService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getOrderIdsByBuyer(Long buyer,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return orderService.getOrderIdsByBuyer(buyer,start,limit);
	
	
	}

	@Override
	public List<Long> getOrderIdsByStatus(Integer status, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return null;
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countOrderIdsByBuyer(Long buyer)throws ServiceException, ServiceDaoException{
		
		return orderService.countOrderIdsByBuyer(buyer);
	
	
	}

	@Override
	public Integer countOrderIdsByStatus(Integer status) throws ServiceException, ServiceDaoException {
		return orderService.countOrderIdsByStatus(status);
	}


	@Override
	public List<Long> getOrderIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return orderService.getOrderIds(start, limit);
	}

	@Override
	public Integer countOrderIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return orderService.countOrderIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return orderService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return orderService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   orderService.deleteList(clz, ids);
		
	}


 
}

==> skill-core-30.0.5-sources.jar: com/ptteng/sca/common/skill/client/OrderSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.common.skill.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.skill.model.Order;
import com.ptteng.common.skill.service.OrderService;

import java.util.List;
import java.util.Map;

public class OrderSCAClient implements OrderService {

    private OrderService orderService;

	public OrderService getOrderService() {
		return orderService;
	}
	
	
	public void setOrderService(OrderService orderService) {
		this.orderService =orderService;
	}
	
	
			   
		@Override
		public Long insert(Order order)throws ServiceException, ServiceDaoException{
		
		return orderService.insert(order);
		          
		
		}	
		  
    	   
		@Override
		public List<Order> insertList(List<Order> orderList)throws ServiceException, ServiceDaoException{
		
		return orderService.insertList(orderList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return orderService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(Order order)throws ServiceException, ServiceDaoException{
		
		return orderService.update(order);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<Order> orderList)throws ServiceException, ServiceDaoException{
		
		return orderService.updateList(orderList);
		          
		
		}	
		  
    	   
		@Override
		public Order getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return orderService.getObjectById(id);
		          
		
		}

	@Override
	public Order getObjectByOrderId(String orderId) throws ServiceException, ServiceDaoException {
		return orderService.getObjectByOrderId(orderId);
	}


	@Override
		public List<Order> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return orderService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getOrderIdsByBuyer(Long buyer,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return orderService.getOrderIdsByBuyer(buyer,start,limit);
	
	
	}

	@Override
	public List<Long> getOrderIdsByStatus(Integer status, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return null;
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countOrderIdsByBuyer(Long buyer)throws ServiceException, ServiceDaoException{
		
		return orderService.countOrderIdsByBuyer(buyer);
	
	
	}

	@Override
	public Integer countOrderIdsByStatus(Integer status) throws ServiceException, ServiceDaoException {
		return orderService.countOrderIdsByStatus(status);
	}


	@Override
	public List<Long> getOrderIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return orderService.getOrderIds(start, limit);
	}

	@Override
	public Integer countOrderIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return orderService.countOrderIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return orderService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}

	@Override
	public Object getObjectByDynamicCondition(Class aClass, Map<String, Object> map, Integer integer, Integer integer1) throws ServiceException, ServiceDaoException {
		return orderService.getObjectByDynamicCondition(aClass, map, integer, integer1);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return orderService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   orderService.deleteList(clz, ids);
		
	}


 
}
